@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::GETTY::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.004';
+  $Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.005';
 }
 # ABSTRACT: BeLike::GETTY when you build your dists
 
@@ -34,14 +34,35 @@ has author => (
   is      => 'ro',
   isa     => 'Str',
   lazy    => 1,
-  default => sub { 'GETTY' },
+  default => sub { $_[0]->payload->{author} || 'GETTY' },
 );
 
 has release_branch => (
   is      => 'ro',
   isa     => 'Str',
   lazy    => 1,
-  default => sub { 'master' },
+  default => sub { $_[0]->payload->{release_branch} || 'master' },
+);
+
+has duckpan => (
+  is      => 'ro',
+  isa     => 'Bool',
+  lazy    => 1,
+  default => sub { $_[0]->payload->{duckpan} },
+);
+
+has no_cpan => (
+  is      => 'ro',
+  isa     => 'Bool',
+  lazy    => 1,
+  default => sub { $_[0]->payload->{no_cpan} },
+);
+
+has no_install => (
+  is      => 'ro',
+  isa     => 'Bool',
+  lazy    => 1,
+  default => sub { $_[0]->payload->{no_install} },
 );
 
 has is_task => (
@@ -58,13 +79,47 @@ has weaver_config => (
   default => sub { $_[0]->payload->{weaver_config} || '@Author::GETTY' },
 );
 
+my @run_options = qw( after_build before_build before_release release after_release test );
+
+for (@run_options) {
+  has "run_".$_ => (
+    is      => 'ro',
+    isa     => 'Str',
+    lazy    => 1,
+    default => sub { $_[0]->payload->{"run_".$_} || "" },
+  );
+}
+
 sub configure {
   my ($self) = @_;
 
   $self->log_fatal("you must not specify both weaver_config and is_task")
     if $self->is_task and $self->weaver_config ne '@Author::GETTY';
 
-  $self->add_bundle('@Basic');
+  $self->log_fatal("you must not specify both author and no_cpan")
+    if $self->no_cpan and $self->author ne 'GETTY';
+
+  if ($self->no_cpan) {
+    $self->add_bundle('@Filter' => {
+      -bundle => '@Basic',
+      -remove => 'ShareDir',
+      -remove => 'UploadToCPAN',
+    });
+  } else {
+    $self->add_bundle('@Basic');
+  }
+
+  if ($self->duckpan) {
+    $self->add_plugins(qw(
+      UploadToDuckPAN
+    ));
+  }
+
+  if ($self->no_install) {
+    $self->add_plugins(qw(
+      MakeMaker::SkipInstall
+    ));
+  }
 
   unless ($self->manual_version) {
     if ($self->is_task) {
@@ -86,6 +141,19 @@ sub configure {
     }
   }
 
+  for (@run_options) {
+    my $net = $_;
+    my $func = 'run_'.$_;
+    if ($self->$func) {
+      my $plugin = join('',map { ucfirst($_) } split(/_/,$_));
+      $self->add_plugins([
+        $plugin => {
+          run => $self->$func,
+        }
+      ]);
+    }
+  }
+
 	$self->add_plugins(qw(
 		PkgVersion
 		MetaConfig
@@ -101,12 +169,14 @@ sub configure {
 		}
 	]);
 
-	$self->add_plugins([
-		'Authority' => {
-			authority => 'cpan:'.$self->author,
-			do_metadata => 1,
-		}
-	]);
+  unless ($self->no_cpan) {
+  	$self->add_plugins([
+  		'Authority' => {
+  			authority => 'cpan:'.$self->author,
+  			do_metadata => 1,
+  		}
+  	]);
+  }
 
   $self->add_plugins([
     'Git::CheckFor::CorrectBranch' => {
@@ -159,7 +229,7 @@ Dist::Zilla::PluginBundle::Author::GETTY - BeLike::GETTY when you build your dis
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -206,9 +276,13 @@ You can configure it (given values are default):
   author = GETTY
   release_branch = master
   weaver_config = @Author::GETTY
+  no_cpan = 0
+  duckpan = 0
+  no_install = 0
 
 If the C<task> argument is given to the bundle, PodWeaver is replaced with
-TaskWeaver and Git::NextVersion is replaced with AutoVersion:
+TaskWeaver and Git::NextVersion is replaced with AutoVersion, you can also
+give independent a bigger major version with C<version>:
 
   [@Author::GETTY]
   task = 1
@@ -219,6 +293,16 @@ are omitted.
   [@Author::GETTY]
   manual_version = 1.222333
 
+You can also use shortcuts for integrating L<Dist::Zilla::Plugin::Run>:
+
+  [@Author::GETTY]
+  run_after_build = script/do_this.pl --dir %s --version %s
+  run_before_build = script/do_this.pl --version %s
+  run_before_release = script/myapp_before1.pl %s
+  run_release = deployer.pl --dir %d --tgz %a --name %n --version %v
+  run_after_release = script/myapp_after.pl --archive %s --version %s
+  run_test = script/tester.pl --name %n --version %v some_file.ext
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<http://www.raudss.us/>
